@@ -1,23 +1,20 @@
 import asyncio
-from functools import wraps
-from typing import Any, Callable, List, Optional, SupportsInt, Tuple, TypeVar, Union
+from typing import Any, Callable, List, Optional, Tuple, TypeVar, Union
 
 import asyncpg
 from asyncpg.transaction import Transaction
-from pypika import PostgreSQLQuery
 
 from tortoise.backends.asyncpg.executor import AsyncpgExecutor
 from tortoise.backends.asyncpg.schema_generator import AsyncpgSchemaGenerator
 from tortoise.backends.base.client import (
-    BaseDBAsyncClient,
     BaseTransactionWrapper,
-    Capabilities,
     ConnectionWrapper,
     NestedTransactionPooledContext,
     PoolConnectionWrapper,
     TransactionContext,
     TransactionContextPooled,
 )
+from tortoise.backends.base_postgres.client import BasePostgresClient, translate_exceptions
 from tortoise.exceptions import (
     DBConnectionError,
     IntegrityError,
@@ -29,56 +26,12 @@ FuncType = Callable[..., Any]
 F = TypeVar("F", bound=FuncType)
 
 
-def translate_exceptions(func: F) -> F:
-    @wraps(func)
-    async def translate_exceptions_(self, *args):
-        try:
-            return await func(self, *args)
-        except (asyncpg.SyntaxOrAccessError, asyncpg.exceptions.DataError) as exc:
-            raise OperationalError(exc)
-        except asyncpg.IntegrityConstraintViolationError as exc:
-            raise IntegrityError(exc)
-        except asyncpg.InvalidTransactionStateError as exc:  # pragma: nocoverage
-            raise TransactionManagementError(exc)
-
-    return translate_exceptions_  # type: ignore
-
-
-class AsyncpgDBClient(BaseDBAsyncClient):
-    DSN_TEMPLATE = "postgres://{user}:{password}@{host}:{port}/{database}"
-    query_class = PostgreSQLQuery
+class AsyncpgDBClient(BasePostgresClient):
     executor_class = AsyncpgExecutor
     schema_generator = AsyncpgSchemaGenerator
-    capabilities = Capabilities("postgres", support_update_limit_order_by=False)
     connection_class = asyncpg.connection.Connection
-    loop = None
-
-    def __init__(
-        self, user: str, password: str, database: str, host: str, port: SupportsInt, **kwargs: Any
-    ) -> None:
-        super().__init__(**kwargs)
-
-        self.user = user
-        self.password = password
-        self.database = database
-        self.host = host
-        self.port = int(port)  # make sure port is int type
-        self.extra = kwargs.copy()
-        # we can't deep copy kwargs because of ssl context
-        # since server_settings is a dict, we copy it again
-        self.server_settings = (self.extra.pop("server_settings", None) or {}).copy()
-        self.schema = self.extra.pop("schema", None)
-        self.application_name = self.extra.pop("application_name", None)
-        self.extra.pop("connection_name", None)
-        self.extra.pop("fetch_inserted", None)
-        self.loop = self.extra.pop("loop", None)
-        self.connection_class = self.extra.pop("connection_class", self.connection_class)
-        self.pool_minsize = int(self.extra.pop("minsize", 1))
-        self.pool_maxsize = int(self.extra.pop("maxsize", 5))
-
-        self._template: dict = {}
-        self._pool: Optional[asyncpg.pool] = None
-        self._connection = None
+    _pool: Optional[asyncpg.Pool]
+    _connection: Optional[asyncpg.connection.Connection] = None
 
     async def create_connection(self, with_db: bool) -> None:
         if self.schema:
@@ -100,11 +53,13 @@ class AsyncpgDBClient(BaseDBAsyncClient):
             **self.extra,
         }
         try:
-            self._pool = await asyncpg.create_pool(None, password=self.password, **self._template)
+            self._pool = await self.create_pool(password=self.password, **self._template)
             self.log.debug("Created connection pool %s with params: %s", self._pool, self._template)
         except asyncpg.InvalidCatalogNameError:
             raise DBConnectionError(f"Can't establish connection to database {self.database}")
-        # Set post-connection variables
+
+    async def create_pool(self, **kwargs) -> asyncpg.Pool:
+        return await asyncpg.create_pool(None, **kwargs)
 
     async def _expire_connections(self) -> None:
         if self._pool:  # pragma: nobranch
@@ -119,25 +74,25 @@ class AsyncpgDBClient(BaseDBAsyncClient):
             self._pool = None
             self.log.debug("Closed connection pool %s with params: %s", self._pool, self._template)
 
-    async def close(self) -> None:
-        await self._close()
-        self._template.clear()
-
-    async def db_create(self) -> None:
-        await self.create_connection(with_db=False)
-        await self.execute_script(f'CREATE DATABASE "{self.database}" OWNER "{self.user}"')
-        await self.close()
+    async def _translate_exceptions(self, func, *args, **kwargs) -> Exception:
+        try:
+            return await func(self, *args, **kwargs)
+        except (asyncpg.SyntaxOrAccessError, asyncpg.exceptions.DataError) as exc:
+            raise OperationalError(exc)
+        except asyncpg.IntegrityConstraintViolationError as exc:
+            raise IntegrityError(exc)
+        except asyncpg.InvalidTransactionStateError as exc:  # pragma: nocoverage
+            raise TransactionManagementError(exc)
 
     async def db_delete(self) -> None:
-        await self.create_connection(with_db=False)
         try:
-            await self.execute_script(f'DROP DATABASE "{self.database}"')
+            return await super().db_delete()
         except asyncpg.InvalidCatalogNameError:  # pragma: nocoverage
             pass
         await self.close()
 
     def acquire_connection(self) -> Union["PoolConnectionWrapper", "ConnectionWrapper"]:
-        return PoolConnectionWrapper(self._pool)
+        return PoolConnectionWrapper(self)
 
     def _in_transaction(self) -> "TransactionContext":
         return TransactionContextPooled(TransactionWrapper(self))
@@ -193,12 +148,6 @@ class AsyncpgDBClient(BaseDBAsyncClient):
                 return list(map(dict, await connection.fetch(query, *values)))
             return list(map(dict, await connection.fetch(query)))
 
-    @translate_exceptions
-    async def execute_script(self, query: str) -> None:
-        async with self.acquire_connection() as connection:
-            self.log.debug(query)
-            await connection.execute(query)
-
 
 class TransactionWrapper(AsyncpgDBClient, BaseTransactionWrapper):
     def __init__(self, connection: AsyncpgDBClient) -> None:
@@ -209,13 +158,13 @@ class TransactionWrapper(AsyncpgDBClient, BaseTransactionWrapper):
         self.connection_name = connection.connection_name
         self.transaction: Transaction = None
         self._finalized = False
-        self._parent = connection
+        self._parent: AsyncpgDBClient = connection
 
     def _in_transaction(self) -> "TransactionContext":
         return NestedTransactionPooledContext(self)
 
     def acquire_connection(self) -> "ConnectionWrapper":
-        return ConnectionWrapper(self._connection, self._lock)
+        return ConnectionWrapper(self._lock, self)
 
     @translate_exceptions
     async def execute_many(self, query: str, values: list) -> None:
