@@ -80,6 +80,6 @@ def mysql_json_filter(field: Term, value: Dict) -> Criterion:
     key_parts = list(map(lambda item: int(item) if item.isdigit() else str(item), key.split("__")))
     operator_ = operator.eq
     if key_parts[-1] in operator_keywords:
-        operator_ = operator_keywords[str(key_parts.pop(-1))]
+        operator_ = operator_keywords[str(key_parts.pop(-1))]  # type: ignore
 
     return operator_(JSONExtract(field, key_parts), filter_value)
