@@ -3,7 +3,7 @@ from typing import Dict, Iterable, Optional, Union
 
 from sanic import Sanic  # pylint: disable=E0401
 
-from tortoise import Tortoise
+from tortoise import Tortoise, connections
 from tortoise.log import logger
 
 
@@ -80,12 +80,12 @@ def register_tortoise(
     @app.listener("before_server_start")  # type:ignore
     async def init_orm(app, loop):  # pylint: disable=W0612
         await Tortoise.init(config=config, config_file=config_file, db_url=db_url, modules=modules)
-        logger.info("Tortoise-ORM started, %s, %s", Tortoise._connections, Tortoise.apps)
+        logger.info("Tortoise-ORM started, %s, %s", connections._get_storage(), Tortoise.apps)
         if generate_schemas:
             logger.info("Tortoise-ORM generating schema")
             await Tortoise.generate_schemas()
 
     @app.listener("after_server_stop")  # type:ignore
     async def close_orm(app, loop):  # pylint: disable=W0612
-        await Tortoise.close_connections()
+        await connections.close_all()
         logger.info("Tortoise-ORM shutdown")
