@@ -15,6 +15,7 @@ from tortoise.fields.data import (
     SmallIntField,
     TextField,
     TimeDeltaField,
+    TimeField,
     UUIDField,
 )
 from tortoise.fields.relational import (
@@ -44,6 +45,7 @@ __all__ = [
     "CharField",
     "DateField",
     "DatetimeField",
+    "TimeField",
     "DecimalField",
     "FloatField",
     "IntEnumField",
