@@ -14,7 +14,7 @@ from pypika.terms import Term
 from tortoise import timezone
 from tortoise.exceptions import ConfigurationError, FieldError
 from tortoise.fields.base import Field
-from tortoise.timezone import get_timezone, get_use_tz, localtime
+from tortoise.timezone import get_default_timezone, get_timezone, get_use_tz, localtime
 from tortoise.validators import MaxLengthValidator
 
 try:
@@ -368,7 +368,6 @@ class DateField(Field, datetime.date):
     SQL_TYPE = "DATE"
 
     def to_python_value(self, value: Any) -> Optional[datetime.date]:
-
         if value is not None and not isinstance(value, datetime.date):
             value = parse_datetime(value).date()
         self.validate(value)
@@ -384,6 +383,61 @@ class DateField(Field, datetime.date):
         return value
 
 
+class TimeField(Field, datetime.time):
+    """
+    Time field.
+    """
+
+    skip_to_python_if_native = True
+    SQL_TYPE = "TIME"
+
+    def __init__(self, auto_now: bool = False, auto_now_add: bool = False, **kwargs: Any) -> None:
+        if auto_now_add and auto_now:
+            raise ConfigurationError("You can choose only 'auto_now' or 'auto_now_add'")
+        super().__init__(**kwargs)
+        self.auto_now = auto_now
+        self.auto_now_add = auto_now | auto_now_add
+
+    def to_python_value(self, value: Any) -> Optional[datetime.time]:
+        if value is not None:
+            if isinstance(value, str):
+                value = datetime.time.fromisoformat(value)
+            if timezone.is_naive(value):
+                value = value.replace(tzinfo=get_default_timezone())
+        self.validate(value)
+        return value
+
+    def to_db_value(
+        self, value: Optional[datetime.time], instance: "Union[Type[Model], Model]"
+    ) -> Optional[datetime.time]:
+
+        # Only do this if it is a Model instance, not class. Test for guaranteed instance var
+        if hasattr(instance, "_saved_in_db") and (
+            self.auto_now
+            or (self.auto_now_add and getattr(instance, self.model_field_name) is None)
+        ):
+            now = timezone.now().time()
+            setattr(instance, self.model_field_name, now)
+            return now
+        if value is not None:
+            if get_use_tz():
+                if timezone.is_naive(value):
+                    warnings.warn(
+                        "TimeField %s received a naive time (%s)"
+                        " while time zone support is active." % (self.model_field_name, value),
+                        RuntimeWarning,
+                    )
+                    value = value.replace(tzinfo=get_default_timezone())
+        self.validate(value)
+        return value
+
+    class _db_mysql:
+        SQL_TYPE = "TIME(6)"
+
+    class _db_postgres:
+        SQL_TYPE = "TIMETZ"
+
+
 class TimeDeltaField(Field, datetime.timedelta):
     """
     A field for storing time differences.
@@ -476,7 +530,7 @@ class JSONField(Field, dict, list):  # type: ignore
                 return self.decoder(value)
             except Exception:
                 raise FieldError(
-                    f"Value {value if isinstance(value,str) else value.decode()} is invalid json value."
+                    f"Value {value if isinstance(value, str) else value.decode()} is invalid json value."
                 )
 
         self.validate(value)
